@@ -229,9 +229,9 @@ def revert_if_failed(keep_leftovers):
             raise
         now = get_status()
         for tag in set(now['tags']).difference(set(before['tags'])):
-            repository.delete(now[tag])
+            repository.delete(now['tags'][tag])
         for branch in set(now['branches']).difference(set(before['branches'])):
-            repository.delete(now[branch])
+            repository.delete(now['branches'][branch])
         for branch_name in ['master', 'develop']:
             repository.resetHard()
             branch = repository.getBranchByName(branch_name)
